@@ -40,6 +40,7 @@ try:
 except ImportError:
     from httplib import BadStatusLine
 import socket
+import subprocess
 import re
 import DistUpgrade.DistUpgradeCache
 from gettext import gettext as _
@@ -84,6 +85,21 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         assert (self._depcache.broken_count == 0 and
                 self._depcache.del_count == 0)
         self.launchpad = None
+        # generate versioned_kernel_pkgs_regexp for later use
+        apt_versioned_kernel_pkgs = apt_pkg.config.value_list(
+            "APT::VersionedKernelPackages")
+        if apt_versioned_kernel_pkgs:
+            self.versioned_kernel_pkgs_regexp = re.compile("(" + "|".join(
+                ["^" + p for p in apt_versioned_kernel_pkgs]) + ")")
+            running_kernel_version = subprocess.check_output(
+                ["uname", "-r"], universal_newlines=True).rstrip()
+            self.running_kernel_pkgs_regexp = re.compile("(" + "|".join(
+                [("^" + p + ".*" + running_kernel_version)
+                 if not p.startswith(".*") else (running_kernel_version + p)
+                 for p in apt_versioned_kernel_pkgs]) + ")")
+        else:
+            self.versioned_kernel_pkgs_regexp = None
+            self.running_kernel_pkgs_regexp = None
 
     def _dpkgJournalDirty(self):
         """
@@ -180,9 +196,9 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
 
     def _strip_epoch(self, verstr):
         " strip of the epoch "
-        l = verstr.split(":")
-        if len(l) > 1:
-            verstr = "".join(l[1:])
+        vers_no_epoch = verstr.split(":")
+        if len(vers_no_epoch) > 1:
+            verstr = "".join(vers_no_epoch[1:])
         return verstr
 
     def _get_changelog_or_news(self, name, fname, strict_versioning=False,
@@ -204,9 +220,9 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         srcver = self._strip_epoch(srcver_epoch)
         #print("bin: %s" % binver)
 
-        l = section.split("/")
-        if len(l) > 1:
-            src_section = l[0]
+        split_section = section.split("/")
+        if len(split_section) > 1:
+            src_section = split_section[0]
 
         # lib is handled special
         prefix = srcpkg[0]
@@ -301,7 +317,6 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                                                          'production',
                                                          version='devel')
 
-
         archive = self.launchpad.archives.getByReference(
             reference='~%s/ubuntu/%s' % (user, ppa)
         )
@@ -354,7 +369,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         self.get_changelog(name)
         try:
             lock.release()
-        except:
+        except Exception as e:
             pass
 
     def get_news(self, name):
@@ -375,7 +390,8 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                     changelogs_uri_ppa = self._extract_ppa_changelog_uri(name)
                     break
                 except Exception:
-                    logging.exception("Unable to connect to the Launchpad API.")
+                    logging.exception("Unable to connect to the Launchpad "
+                                      "API.")
         # Try non official changelog location
         changelogs_uri_binary = \
             self._guess_third_party_changelogs_uri_by_binary(name)
