@@ -26,7 +26,6 @@ import gi
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 from gi.repository import Gdk
-
 import warnings
 warnings.filterwarnings(
     "ignore", "Accessed deprecated property", DeprecationWarning)
@@ -35,10 +34,13 @@ import logging
 import datetime
 import dbus
 import os
+import subprocess
 
 import HweSupportStatus.consts
+from .Core.LivePatchSocket import LivePatchSocket
 
 from gettext import gettext as _
+from gettext import ngettext
 
 
 class Dialog(object):
@@ -142,6 +144,49 @@ class InternalDialog(BuilderDialog):
             self.main_container.add(content_widget)
         self.main_container.set_visible(bool(content_widget))
 
+    def on_livepatch_status_ready(self, active, cs, ps, fixes):
+        self.set_desc(None)
+
+        if not active:
+            return
+
+        needs_reschedule = False
+
+        if cs == "needs-check":
+            needs_reschedule = True
+        elif cs == "check-failed":
+            pass
+        elif cs == "checked":
+            if ps == "unapplied" or ps == "applying":
+                needs_reschedule = True
+            elif ps == "applied":
+                fixes = [fix for fix in fixes if fix.patched]
+                d = ngettext("%d Livepatch update applied since the last "
+                             "restart.",
+                             "%d Livepatch updates applied since the last "
+                             "restart.",
+                             len(fixes)) % len(fixes)
+                self.set_desc(d)
+            elif ps == "applied-with-bug" or ps == "apply-failed":
+                fixes = [fix for fix in fixes if fix.patched]
+                d = ngettext("%d Livepatch update failed to apply since the "
+                             "last restart.",
+                             "%d Livepatch updates failed to apply since the "
+                             "last restart.",
+                             len(fixes)) % len(fixes)
+                self.set_desc(d)
+            elif ps == "nothing-to-apply":
+                pass
+            elif ps == "unknown":
+                pass
+
+        if needs_reschedule:
+            self.lp_socket.get_status(self.on_livepatch_status_ready)
+
+    def check_livepatch_status(self):
+        self.lp_socket = LivePatchSocket()
+        self.lp_socket.get_status(self.on_livepatch_status_ready)
+
 
 class StoppedUpdatesDialog(InternalDialog):
     def __init__(self, window_main):
@@ -166,6 +211,7 @@ class NoUpdatesDialog(InternalDialog):
         self.add_settings_button()
         self.focus_button = self.add_button(Gtk.STOCK_OK,
                                             self.window_main.close)
+        self.check_livepatch_status()
 
 
 class DistUpgradeDialog(InternalDialog):
@@ -191,8 +237,10 @@ class DistUpgradeDialog(InternalDialog):
                 extra_args = extra_args + " -d"
             if self.window_main.options.use_proposed:
                 extra_args = extra_args + " -p"
-            if self.window_main.options.sandbox:
-                extra_args = extra_args + " -s"
+        # Workaround restricted root access to graphical applications under
+        # wayland
+        if 'WAYLAND_DISPLAY' in os.environ:
+            subprocess.run(["xhost", "+si:localuser:root"])
         os.execl("/bin/sh", "/bin/sh", "-c",
                  "/usr/bin/pkexec /usr/bin/do-release-upgrade "
                  "--frontend=DistUpgradeViewGtk3%s" % extra_args)
