@@ -26,6 +26,7 @@ from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
+from gi.repository import GObject
 
 GdkX11  # pyflakes
 
@@ -94,7 +95,9 @@ class UpdateManager(Gtk.Window):
 
         # Keep window at a constant size
         ctx = self.get_style_context()
-        ctx.connect("changed", lambda ctx: self.resize_to_standard_width())
+        self.style_changed = ctx.connect("changed",
+                                         lambda ctx:
+                                             self.resize_to_standard_width())
 
         # Signals
         self.connect("delete-event", self._on_close)
@@ -135,9 +138,11 @@ class UpdateManager(Gtk.Window):
         if dpi <= 0:
             dpi = 96
         ctx = self.get_style_context()
+        GObject.signal_handler_block(ctx, self.style_changed)
         size = ctx.get_property("font-size", Gtk.StateFlags.NORMAL)
         width = dpi / 72 * size * num_em
         self.set_size_request(width, -1)
+        GObject.signal_handler_unblock(ctx, self.style_changed)
 
     def on_initial_focus_in(self, widget, event):
         """callback run on initial focus-in (if started unmapped)"""
@@ -192,9 +197,11 @@ class UpdateManager(Gtk.Window):
         except SystemError:
             pass
         cmd = ["/usr/bin/software-properties-gtk",
-               "--open-tab", "2",
-               "--toplevel", "%s" % self.get_window().get_xid()
-               ]
+               "--open-tab", "2"]
+
+        if "WAYLAND_DISPLAY" not in os.environ:
+            cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
+
         self._look_busy()
         try:
             p = subprocess.Popen(cmd)
@@ -342,7 +349,8 @@ class UpdateManager(Gtk.Window):
                 self.hwe_replacement_packages = []
                 for pkgname in packages:
                     pkgname = pkgname.decode('utf-8')
-                    if pkgname in self.cache and not self.cache[pkgname].is_installed:
+                    if pkgname in self.cache and \
+                            not self.cache[pkgname].is_installed:
                         self.hwe_replacement_packages.append(pkgname)
                 # for debugging
                 # print(self.hwe_replacement_packages)
@@ -409,7 +417,7 @@ class UpdateManager(Gtk.Window):
         # listening on dbus
         try:
             bus = dbus.SessionBus()
-        except:
+        except Exception as e:
             print("warning: could not initiate dbus")
             return
         try:
@@ -447,7 +455,7 @@ class UpdateManagerDbusController(dbus.service.Object):
         try:
             self.parent.start_install()
             return True
-        except:
+        except Exception as e:
             return False
 
     def _on_network_alert(self, watcher, state):
